==> patch-2.3.5.0.zip: app/language/en/login.php <==
<?php

return array(

	// Index method Language
	'indexPageName'     => 'Login',
	'indexPage_message' => 'Enter your <b>credentials</b> below',
	'sleep'             => 'Locked',
	'sleep_message'     => 'For your security, we\'ve temporarily logged you out.',

	// Password Rest method
	'passwordResetPageName' => 'Password Reset',
	'passwordReset_message' => 'Enter your <b>Username</b>',

	// Common For all Methods
	'401U'      => 'Authentication token has <b>expired.</b>',
	'passwordChanged' => 'User Password updated successfully.',
	'401'       => 'The <b>password</b> is incorrect.',
	'421'       => 'Device session <b>expired.</b>',
	'416'       => 'Account <b>blocked</b> or <b>expired.</b>',
	'403'       => 'Account <b>not active</b>',
	'424'       => 'Account in use from <b>another device</b>.',
	'400'       => 'The <b>Parablu Installation name</b> is invalid, or the entered username/email Id or password combination is invalid.',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
);

==> patch-2.5.3.11.zip: app/language/en/login.php <==
<?php

return array(

	// Index method Language
	'indexPageName'     => 'Login',
	'indexPage_message' => 'Enter your <b>credentials</b> below',
	'sleep'             => 'Locked',
	'sleep_message'     => 'Please check if multiple login sessions exist for the same user.',

	// Password Rest method
	'passwordResetPageName' => 'Password Reset',
	'passwordReset_message' => 'Enter your <b>Username</b>',

	// Common For all Methods
	'401U'      => 'Authentication token has <b>expired.</b>',
	'passwordChanged' => 'User Password updated successfully.',
	'401'       => 'The <b>password</b> is incorrect.',
	'421'       => 'Device session <b>expired.</b>',
	//'416'       => 'Account <b>blocked</b> or <b>expired.</b>',
	'416'       => 'Licence <b>expired.</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       => 'Account <b>not active</b>',
	'424'       => 'Account in use from <b>another device</b>.',
	'440'       => 'Either username or password is wrong, please check again if still not working contact your administrator',
    '441'       => 'Either username or password is wrong, please check again if still not working contact your administrator',
	'400'       => 'The <b>Parablu Installation name</b> is invalid, or the entered username or password combination is invalid.',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
);
